Monty Python's Flying Circus: Just the Words - Episode 8

# Episode Eight: Full frontal nudity

Army protection racket
Vox pops on full frontal nudity
Art critic - the place of the nude
Buying a bed
Hermits
Dead parrot
The flasher
Hell's Grannies

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| We see the 'It's' man sitting in the countryside in a garden lounger chair. A sexy young lady in a bikini hands him a glass of wine and gently helps him up and walks him to the camera. Looking very pleased with himself he sips the wine as she caresses him. Then she hands him a smoking round anarchist's type bomb (with 'Bomb' written on it). He realizes what it is only as he says:
It's Man | It's...
Voice Over | 'MONTY PYTHON'S FLYING CIRCUS'
| Cartoon credits. SUPERIMPOSED CAPTION: 'EPISODE 12B: FULL FRONTAL NUDITY' Cut to vox pops.
Pepperpot | Speaking as a public opinion poll, I've had enough of the permissive society.
Man In Dirty Raincoat | I havn't had enough of the permissive society.
| CAPTION: 'IN THIS PERFORMANCE THE PART OF DAVID HEMMINGS WILL BE PLAYED BY A PIECE OF WOOD' Cut to policeman.
Policeman | I would not appear in a frontal nude scene unless it was valid.
| Stock film of the army. Tanks rolling, troops moving forward etc. Stirring military music.
Voice Over | In 1943, a group of British Army Officers working deep behind enemy lines, carried out one of the most dangerous and heroic raids in the history of warfare. But that's as maybe. And now . . .
| SUPERIMPOSED CAPTION: 'AND NOW . . . UNOCCUPIED BRITAIN 1970' Cut to colonel's office. Colonel is seated at desk.
Colonel | Come in, what do you want?
| Private Watkins enters and salutes.
Watkins | I'd like to leave the army please, sir.
Colonel | Good heavens man, why?
Watkins | It's dangerous.
Colonel | What?
Watkins | There are people with guns out there, sir.
Colonel | What?
Watkins | Real guns, sir. Not toy ones, sir. Proper ones, sir. They've all got 'em. All of 'em, sir. And some of 'em have got tanks.
Colonel | Watkins, they are on our side.
Watkins | And grenades, sir. And machine guns, sir. So I'd like to leave, sir, before I get killed, please.
Colonel | Watkins, you've only been in the army a day.
Watkins | I know sir but people get killed, properly dead, sir, no barley cross fingers, sir. A bloke was telling me, if you're in the army and there's a war you have to go and fight.
Colonel | That's true.
Watkins | Well I mean, blimey, I mean if it was a big war somebody could be hurt.
Colonel | Watkins why did you join the army?
Watkins | For the water-skiing and for the travel, sir. And not for the killing, sir. I asked them to put it on my form, sir - no killing.
Colonel | Watkins are you a pacifist?
Watkins | No sir, I'm not a pacifist, sir. I'm a coward.
Colonel | That's a very silly line. Sit down.
Watkins | Yes sir. Silly, sir. (sits in corner)
Colonel | Awfully bad.
| Knock at the door, sergeant enters, and salutes.
Sergeant | Two civilian gentlemen to see you ... sir!
Colonel | Show them in please, sergeant.
Sergeant | Mr Dino Vercotti and Mr Luigi Vercotti.
| The Vercotti brothers enter. They wear Mafia suits and dark glasses.
Dino | Good morning, colonel.
Colonel | Good morning gentlemen. Now what can I do for you.
Luigi | (looking round office casually)You've ... you've got a nice army base here, colonel.
Colonel | Yes.
Luigi | We wouldn't want anything to happen to it.
Colonel | What?
Dino | No, what my brother means is it would be a shame if... (he knocks something off mantel)
Colonel | Oh.
Dino | Oh sorry, colonel.
Colonel | Well don't worry about that. But please do sit down.
Luigi | No, we prefer to stand, thank you, colonel.
Colonel | All right. All right. But what do you want?
Dino | What do we want, ha ha ha.
Luigi | Ha ha ha, very good, colonel.
Dino | The colonel's a joker, Luigi.
Luigi | Explain it to the colonel, Dino.
Dino | How many tanks you got, colonel?
Colonel | About five hundred altogether.
Luigi | Five hundred! Hey!
Dino | You ought to be careful, colonel.
Colonel | We are careful, extremely careful.
Dino | 'Cos things break, don't they?
Colonel | Break?
Luigi | Well everything breaks, don't it colonel. (he breaks something on desk) Oh dear.
Dino | Oh see my brother's clumsy colonel, and when he gets unhappy he breaks things. Like say, he don't feel the army's playing fair by him, he may start breaking things, colonel.
Colonel | What is all this about?
Luigi | How many men you got here, colonel?
Colonel | Oh, er ... seven thousand infantry, six hundred artillery, and er, two divisions of paratroops.
Luigi | Paratroops, Dino.
Dino | Be a shame if someone was to set fire to them.
Colonel | Set fire to them?
Luigi | Fires happen, colonel.
Dino | Things burn.
Colonel | Look, what is all this about?
Dino | My brother and I have got a little proposition for you colonel.
Luigi | Could save you a lot of bother.
Dino | I mean you're doing all right here aren't you, colonel.
Luigi | Well suppose some of your tanks was to get broken and troops started getting lost, er, fights started breaking out during general inspection, like.
Dino | It wouldn't be good for business would it, colonel?
Colonel | Are you threatening me?
Dino | Oh, no, no, no.
Luigi | Whatever made you think that, colonel?
Dino | The colonel doesn't think we're nice people, Luigi.
Luigi | We're your buddies, colonel.
Dino | We want to look after you.
Colonel | Look after me?
Luigi | We can guarantee you that not a single armoured division will get done over for fifteen bob a week.
Colonel | No, no, no.
Luigi | Twelve and six.
Colonel | No, no, no.
Luigi | Eight and six ... five bob...
Colonel | No, no this is silly.
Dino | What's silly?
Colonel | No, the whole premise is silly and it's very badly written. I'm the senior officer here and I haven't had a funny line yet. So I'm stopping it.
Dino | You can't do that!
Colonel | I've done it. The sketch is over.
Watkins | I want to leave the army please sir, it's dangerous.
Colonel | Look, I stopped your sketch five minutes ago. So get out of shot. Right director! Close up. Zoom in on me. (camera zooms in) That's better.
Luigi | (off screen) It's only 'cos you couldn't think of a punch line.
Colonel | Not true, not true. It's time for the cartoon. Cue telecine, ten, nine, eight...
| Cut to telecine countdown.
Dino | (off screen) The general public's not going to understand this, are they?
Colonel | (off screen) Shut up you eyeties!
| Cartoon rubbish entitled 'Full Frontal Nudity': Written, created and concieved off the back of a lorry by a demented American. Cut to two naked men.
Man | Full frontal nudity - never. What do you think, Barbara?
Barbara | Oh, no, no, no...unless it was artistically valid, of course.
| Cut to a stockbroker.
Stockbroker | Full frontal nudity? Yes I'd do it, if it was valid. Or if the money was valid, and if it were a very small part.
| Cut to art critic examining a nude painting. CAPTION: 'AN ART CRITIC' He sees the camera and starts guiltily.
Art Critic | Good evening. I'd like to talk to you tonight about the place of the nude in my bed ... um ... in the history of my bed ... of art, of art, I'm sorry. The place of the nude in the history of tart... call-girl... I'm sorry. I'll start again... Bum ... oh what a giveaway. The place of the nude in art. (a seductively dressed girl enters slinkily) Oh hello there father, er confessor, professor, your honour, your grace ...
Girl (Katya Wyeth) | (cutely) I'm not your Grace, I'm your Elsie.
Art Critic | What a terrible joke!
Girl | (crying) But it's my only line!
| Cut to an idyllic countryside. Birds sing etc. as the camera starts a lyrical pan across the fields.
Voice Over | (and SUPERIMPOSED CAPTION) 'BUT THERE LET US LEAVE THE ART CRITIC TO STRANGLE HIS WIFE AND MOVE ON TO PASTURES NEW'
| After about ten seconds of mood setting the camera suddenly comes across the art critic strangling his wife in middle foreground. As the camera passes him he hums nervously and tries to look as though he isn't strangling anybody. The camera doesn't stop panning, and just as it goes off him we see him start strangling again. The pan carries on and catches up with a bridegroom carrying his bride across a field and finally arriving in a high street where, breathless and panting, he carries her through traffic and into a large department store. Finally cut to the furniture department of the store. The bridegroom and bride enter, he puts her down and addresses one of the assistants.
Groom | We want to buy a bed, please.
Mr Lambert | Og, certainly, I'll, I'll get someone to help you. (calling off) Mr Verity!
Mr Verity | Can I help you, sir?
Groom | Er yes. We'd like to buy a bed...a double bed...about fifty pounds?
Verity | Oh no, I'm afraid not, sir. Our cheapest bed is eight hundred pounds, sir.
Groom | Eight hundred pounds!
Lambert | Or, er, perhaps I should have explained. Mr Verity does tend to exaggerate, so every figure he gives you will be ten times too high. Otherwise he's perfectly all right, perfectly ha, ha, ha.
Groom | Oh I see. I see. (to Verity) So your cheapest bed then is eighty pounds?
Verity | Eight hundred pounds, yes, sir.
Groom | And how wide is it?
Verity | Er, the width is, er, sixty feet wide.
Groom | Oh... (laughing politely he mutters to wife) six foot wide, eh. And the length?
Verity | The length is ... er ... (calls off) Lambert! What is the length of the Comfydown Majorette?
Lambert | Er, two foot long.
Groom | Two foot long?
Verity | Ah yes, you have to remember of course, to multiply everything Mr Lambert says by three. Er, it's nothing he can help, you understand. Apart from that he's perfectly all right.
Groom | I see, I'm sorry.
Verity | But it does mean that when he says a bed is two foot wide, it is in fact sixty foot wide.
Groom | Oh, yes I see...
Verity | And that's not counting the mattress.
Groom | Oh, how much is that?
Verity | Er, Mr Lambert will be able to help you there. (calls) Lambert! Will you show these twenty good people the, er, dog kennels, please?
Lambert | Mm? Certainly.
Groom | Dog kennel? No, no, no, mattresses, mattresses!
Verity | Oh no, no you have to say dog kennel to Mr Lambert because if you say mattress he puts a bag over his head. I should have explained. Apart from that he's really all right.
| They go to Lambert.
Groom | Ah, hum, er we'd like to see the dog kennels please.
Lambert | Dog kennels?
Groom | Yes, we want to see the dog kennels.
Lambert | Ah yes, well that's the pets' department. Second floor.
Groom | Oh, no, no, we want to see the dog kennels.
Lambert | Yes, pets department second floor.
Groom | No, we don't really want to see dog kennels only your colleague said we ought to...
Lambert | Oh dear, what's he been telling you now?
Groom | Well, he said we should say dog kennels instead of mattress.
| Lambert puts bag over head
Groom | (looking around) Oh dear. Hello?
Verity | Did you say mattress?
Groom | Well, a little yes.
Verity | I did ask you not to say mattress, didn't I? Now I've got to stand in the tea chest. (he gets in the chest and sings) 'And did those feet in ancient times, walk upon England's mountains green...'
| The manager enters.
Manager | Oh dear, did somebody say mattress to Mr Lambert?
| Manager and Verity continue to sing. Lambert takes bag off head, manager exits after pointing a warning finger at bride and groom.
Verity | (Getting out of chest) He should be all right now, but don't, you know...don't! (exits)
Groom | Oh, no, no, no. er,, we'd like to see, see the dog kennels please?
Lambert | Yes, second floor.
Groom | No, no, look these (pointing) dog kennels here, see?
Lambert | Mattresses?
Groom | Oh (jumps)...yes.
Lambert | Well, if you meant mattress, why dodn't you say a mattress? I mean, it's very confusing for me if you go and say dog kennels when you mean mattress. Why not just say mattress?
Groom | Well, I mean you put a bag over your head last time I said mattress.
| Bag goes on. Groom looks around guiltily. Verity walks in. Verity heaves a sigh, jumps in box. Manager comes in and joins him, they sing 'And did those feet...'. Another assistant comes in.
Assistant | Did somebody say mattress to Mr Lambert?
Verity | Twice.
Assistant | Hey, everybody, somebody said mattress to Mr Lambert, twice.
| Assistant, groom and bride join in the therapy.
Verity | It's not working. We need more!
| Cut to crowd in St. Peter's Square singing 'Jerusalem'. Cut to department store. Lambert takes the bag off his head and looks at groom and bride.
Lambert | Now, er, can I help you?
Bride | We want a mattress.
| Lambert immediately puts bag back on head.
All | Oh. What did you say that for? What did you say that for?
Bride | (weeping) But it's my only line!
All | Well, you didn't have to say it.
| They all hop off. She howls. Cut to vox pops.
African Native | Full frontal nudity - not in this part of Esher.
Chartered Accountant | I would only perform in a scene in which there was full frontal nudity.
| Cut to colonel.
Colonel | Now, I've noticed a tendency for this programme to get rather silly. Now I do my best to keep things moving along, but I'm not having things getting silly. Those two last sketches I did got very silly indeed, and that last one about the bed was even sillier. Now, nobody likes a good laugh more than I do...except perhaps my wife and some of her friends...oh yes and Captain Johnston. Come to think of it most people likes a good laugh more than I do. But that's beside the point. Now, let's have a good clean healthy outdoor sketch. Get some air into your lungs. Ten, nine, eight and all that.
| Cut to two hermits on a hillside.
First Hermit | Hello, are you a hermit by any chance?
Second Hermit | Yes that's right. Are you a hermit?
First Hermit | Yes, I certainly am.
Second Hermit | Well I never. What are you getting away from?
First Hermit | Oh you know, the usual - people, chat, gossip, you know.
Second Hermit | Oh I certainly do - it was the same with me. I mean there comes a time when you realize there's no good frittering your life away in idleness and trivial chit-chat. Where's your cave?
First Hermit | Oh, up the goat track, first on the left.
Second Hermit | Oh they're very nice up there, aren't they?
First Hermit | Yes they are, I've got a beauty.
Second Hermit | A bit drafty though, aren't they?
First Hermit | No, we've had ours insulated.
Second Hermit | Oh yes.
First Hermit | Yes, I used birds' nests, moss and oak leaves round the outside.
Second Hermit | Oh, sounds marvellous.
First Hermit | Oh it's a treat, it really is, 'cos otherwise those stone caves can be so grim.
Second Hermit | Yes they really can be, can't they? They really can.
First Hermit | Oh yes.
| Third hermit passes by.
Third Hermit | Morning Frank.
Second Hermit | Morning Norman. Talking of moss, er you know Mr Robinson?
First Hermit | With the, er, green loin cloth?
Second Hermit | Er no, that's Mr Seagrave. Mr Robinson's the hermit who lodges with Mr Seagrave.
First Hermit | Oh I see, yes.
Second Hermit | Yes well he's put me onto wattles.
First Hermit | Really?
Second Hermit | Yes. Swears by them. Yes.
| Fourth hermit passes by.
Fourth Hermit | Morning Frank.
Second Hermit | Morning Lionel. Well he says that moss tends to fall off the cave walls during cold weather. You know you might get a really bad spell and half the moss drops off the cave wall, leaving you cold.
First Hermit | Oh well, Mr Robinson's cave's never been exactly nirvana has it?
Second Hermit | Well, quite, that's what I mean. Anyway, Mr Rogers, he's the, er, hermit...
First Hermit | ... on the end.
Second Hermit | . .. up at the top, yes. Well he tried wattles and he came out in a rash.
First Hermit | Really?
Second Hermit | Yes, and there's me with half a wall wattled, I mean what'll I do?
First Hermit | Well why don't you try birds nests like I've done? Or else, dead bracken.
Fifth Hermit | (calling from a distance) Frank!
Second Hermit | Yes Han.
Fifth Hermit | Can I borrow your goat?
Second Hermit | Er, yes that'll be all right. Oh leave me a pint for breakfast will you? ... (to first hermit) You see, you know that is the trouble with living half way up a cliff - you feel so cut off. You know it takes me two hours every morning to get out onto the moors, collect my berries, chastise myself, and two hours back in the evening.
First Hermit | Still there's one thing about being a hermit, at least you meet people.
Second Hermit | Oh yes, I wouldn't go back to public relations.
First Hermit | Oh well, bye for now Frank, must toddle.
Colonel | (coming on) Right, you two hermits, stop that sketch. I think it's silly.
Second Hermit | What?
Colonel | It's silly.
Second Hermit | What do you mean, you can't stop it - it's on film.
Colonel | That doesn't make any difference to the viewer at home, does it? Come on, get out. Out. Come on out, all of you. Get off, go on, all of you. Go on, move, move. Go on, get out. Come on, get out, move, move.
| He shoos them and the film crew off the hillside.
| ANIMATION: including dancing Botticelli Venus, which links to pet shop: Mr. Praline walks into the shop carrying a dead parrot in a cage. He walks to counter where shopkeeper tries to hide below cash register.
Praline | Hello, I wish to register a complaint...Hello? Miss?
Shopkeeper | What do you mean, miss?
Praline | Oh I'm sorry, I have a cold. I wish to make a complaint!
Shopkeeper | Sorry, we're closing for lunch.
Praline | Never mind that, my lad. I wish to complain about this parrot what I purchased not half an hour ago from this very boutique.
Shopkeeper | Oh yes, the, the Norwegian Blue. What's wrong with it?
Praline | I'll tell you what's wrong with it, my lad. It's dead, that's what's wrong with it!
Shopkeeper | No, no, it's resting, look!
Praline | Look my lad, I know a dead parrot when I see one, and I'm looking at one right now.
Shopkeeper | No no sir. it's not dead. It's resting!
Praline | Resting?
Shopkeeper | Yeah, remarkable bird, the Norwegian Blue, beautiful plumage, innit?
Praline | The plumage don't enter into it - it's stone dead.
Shopkeeper | No, no - it's just resting!
Praline | All right then, if it's restin', I'll wake him up! (shouts into cage) Hello Polly! I've got a nice cuttlefish for you when you wake up, Polly Parrot!
Shopkeeper | (jogging the cage) There, it moved!
Praline | No, he didn't. That was you pushing the cage!
Shopkeeper | I did not.
Praline | Yes, you did! (takes parrot out of cage, shouts) Hello Polly, Polly (bangs it against the counter) Polly Parrot, wake up. Polly. (throws it in the air and lets it fall to the floor) Now that's what I call a dead parrot.
Shopkeeper | No, no. It's stunned.
Praline | Look my lad, I've had just about enough of this. That parrot is definitely deceased. And when I bought it not half an hour ago, you assured me that its lack of movement was due to it being tired and shagged out after a long squawk.
Shopkeeper | It's probably pining for the fjords.
Praline | Pining for the fjords, what kind of talk is that? Look, why did it fall flat on its back the moment I got it home?
Shopkeeper | The Norwegian Blue prefers kipping on it's back! Beautiful bird, lovely plumage!
Praline | Look, I took the liberty of examining that parrot, and I discovered the only reason that it had been sitting on its perch in the first place was that it had been nailed there.
Shopkeeper | Well of course it was nailed there. Otherwise it would muscle up to those bars and voom.
Praline | Look matey (picks up the parrot) this parrot wouldn't voom if you put four thousand volts through it! It's bleedin' demised!
Shopkeeper | It's not, it's pining!
Praline | It's not pining, it's passed on. This parrot is no more! It has ceased to be. It's expired and gone to meet its maker.This is a late parrot. It's a stiff. Bereft of life, it rests in peace. If you hadn't nailed it to the perch it would be pushing up the daisies. It's rung down the curtain and joined the choir invisible. This is an ex-parrot.
Shopkeeper | Well, I'd better replace it, then.
Praline | (to camera) If you want to get anything done in this country you've got to complain till you're blue in the mouth.
Shopkeeper | Sorry guv, we're right out of parrots.
Praline | I see. I see. I get the picture.
Shopkeeper | (pause) I got a slug.
Praline | Does it talk?
Shopkeeper | Not really, no.
Praline | Well, it's scarcely a replacement, then is it?
Shopkeeper | Listen, I'll tell you what, (handing over a card) tell you what, if you go to my brother's pet shop in Bolton he'll replace your parrot for you.
Praline | Bolton eh?
Shopkeeper | Yeah.
Praline | All right.
| He leaves, holding the parrot. CAPTION: 'A SIMILAR PET SHOP IN BOLTON; LANCS' Close-up of sign on door reading: 'Similar Pet Shops, Ltd.' Pull back from sign to see same pet shop. Shopkeeper now has moustache. Praline walks into shop. He looks around with interest, noticing the empty parrot cage still on the floor.
Praline | Er, excuse me. This is Bolton, is it?
Shopkeeper | No, no it's, er, Ipswich.
Praline | (to camera) That's Inter-City Rail for you. (leaves)
| Man in porter's outfit standing at complaints desk for railways. Praline approaches.
Praline | I wish to make a complaint.
Porter | I don't have to do this, you know.
Praline | I beg your pardon.
Porter | I'm a qualified brain surgeon. I only do this because I like being my own boss.
Praline | Er, excuse me, this is irrelevant, isn't it.
Porter | Oh yeah, it's not easy to pad these out to thirty minutes.
Praline | Well I wish to make a complaint. I got on the Bolton train and found myself deposited here in Ipswich.
Porter | No, this is Bolton.
Praline | (to camera) The pet shop owner's brother was lying.
Porter | Well you can't blame British Rail for that.
Praline | If this is Bolton, I shall return to the pet shop.
| CAPTION: 'A LITTLE LATER LTD' Praline walks into the shop again.
Praline | I understand that this is Bolton.
Shopkeeper | Yes.
Praline | Well, you told me it was Ipswich.
Shopkeeper | It was a pun.
Praline | A pun?
Shopkeeper | No, no, not a pun, no. What's the other thing which reads the same backwards as forwards?
Praline | A palindrome?
Shopkeeper | Yes, yes.
Praline | It's not a palindrome. The palindrome of Bolton would be Notlob. It don't work.
Shopkeeper | Look, what do you want.
Praline | No I'm sorry, I'm not prepared to pursue my line of enquiry any further as I think this is getting too silly.
Colonel | (coming in) Quite agree. Quite agree. Silly. Silly...silly. Right get on with it. Get on with it.
| Cut to announcer eating a yoghurt.
Announcer | (seeing camera) Oh...er...oh...um. Oh!...er... (shuffles paper) I'm sorry...and now frontal nudity.
| Cut to tracking or hand-held shot down street, keeping up with extremely shabby man in long overcoat. His back is to the camera. He passes two pepperpots and a girl. As he passes each one he opens his coat wide. They react with shocked horror. He does this three times, after the third time he turns to camera and opens his coat wide. He has a big sign hanging round his neck, covering his chest. It says 'boo'. Cut back to announcer eating yoghurt. The colonel comes in and nudges him.
Announcer | Oh, oh I'm sorry. I thought the film was longer. (shuffling papers) Ah. Now Notlob, er, Bolton.
| Cut to grannies film, which opens with a pan across Bolton. Voice of reporter.
Voice Over | This is a frightened city. Over these houses, over these streets hangs a pall of fear. Fear of a new kind of violence which is terrorizing the city. Yes, gangs of old ladies attacking defenseless, fit young men.
| Film of old ladies beating up two young men; then several grannies walking aggressively along street, pushing passers-by aside.
First Young Man | Well they come up to you, like, and push you - shove you off the pavement, like. There's usually four or five of them.
Second Young Man | Yeah, this used to be a nice neighbourhood before the old ladies started moving in. Nowadays some of us daren't even go down to the shops.
Third Young Man | Well Mr Johnson's son Kevin, he don't go out any more. He comes back from wrestling and locks himself in his room.
| Film of grannies harrassing an attractive girl.
Voice Over | What are they in it for, these old hoodlums, these layabouts in lace?
First Granny | (voice over) Well it's something to do isn't it?
Second Granny | (voice over) It's good fun.
Third Granny | (voice over) It's like you know, well, innit, eh?
Voice Over | Favourite targets for the old ladies are telephone kiosks.
| Film of grannies carrying off a telephone kiosk; then painting slogans on a wall.
Policeman | (coming up to them) Well come on, come on, off with you. Clear out, come on get out of it. (they clear off, he turns to camera) We have a lot of trouble with these oldies. Pension day's the worst - they go mad. As soon as they get their hands on their money they blow it all on milk, bread, tea, tin of meat for the cat.
| Cut to cinema.
Cinema Manager | Yes, well of course they come here for the two o'clock matinee, all the old bags out in there, especially if it's something like 'The Sound of Music'. We get seats ripped up, hearing aids broken, all that sort of thing.
| A policeman hustles two grannies out of the cinema. Cut to reporter walking along street.
Reporter | The whole problem of these senile delinquents lies in their complete rejection of the values of contemporary society. They've seen their children grow up and become accountants, stockbrokers and even sociologists, and they begin to wonder if it is all really...(disappears downwards rapidly) arggh!
| Shot of two grannies replacing manhole cover. Cut to young couple.
Fourth Young Man | Oh well we sometimes feel we're to blame in some way for what our gran's become. I mean she used to be happy here until she, she started on the crochet.
Reporter | (off-screen) Crochet?
Fourth Young Man | Yeah. Now she can't do without it. Twenty balls of wool a day, sometimes. If she can't get the wool she gets violent. What can we do about it?
| Film of grannies on motorbikes roaring down streets and through a shop. One has 'Hell's Grannies' on her jacket.
Voice Over | But this is not just an old ladies' town. There are other equally dangerous gangs - such as the baby snatchers.
| Film of five men in baby outfits carrying off a young man from outside a shop. Cut to distraught wife.
Wife (Rita Davies) | I just left my husband out here while I went in to do some shopping and I came back and he was gone. He was only forty-seven.
Voice Over | And on the road too, vicious gangs of keep left signs.
| Film: two keep-left signs attack a vicar.
Colonel | (coming up and stopping them) Right, right, stop it. This film's got silly. Started off with a nice little idea about grannies attacking young men, but now it's got silly. This man's hair is too long for a vicar too. These signs are pretty badly made. Right, now for a complete change of mood.
| Cut to man in dirty raincoat.
Man In Dirty Raincoat | I've heard of unisex but I've never had it.
| Cut to 'It's' man still holding smoking bomb.
Voice Over | David Hemmings appeared by permission of the National Forestry Commission.
| SUPERIMPOSED ROLLER CAPTION: '"FULL FRONTAL NUDITY" WAS CONCIEVED, WRITTEN AND PERFORMED BY...(CREDITS)' The 'It's' man realizes that he has a bomb and runs off still carrying it. As the credits end it explodes.